--- layout: template title: API - pyatv.storage.memory_storage permalink: /api/storage/memory_storage/ link_group: api ---

# Module `pyatv.storage.memory_storage`

Memory storage module.

Browse git

## Classes

`class MemoryStorage`

  Memory based storage module.

  This storage module stores settings in memory and everything stored with it will be forgotten when restarting the python interpreter.

  Initialize a new AbstractStorage instance.

  Browse git

  ### Ancestors

  - AbstractStorage
  - Storage
  - abc.ABC

  ### Inherited members

  - `AbstractStorage`:
    - `changed`
    - `get_settings`
    - `load`
    - `mark_as_saved`
    - `remove_settings`
    - `save`
    - `settings`
    - `storage_model`
    - `update_settings`